class NegativeDiscount(Exception):
    def __init__(self):
        print("discount can't be negative")

class NegativeRoom(Exception):
    def __init__(self):
        print("not enough available room(s)")

class Room:
    def __init__(self,price,availablenumber):
        self.price = price
        self.availablenumber=availablenumber

    def modifyprice(self,newprice):
        self.price=newprice

    def discountprice(self, discount=1):
        if discount < 0:
            raise NegativeDiscount
        self.price*=discount

    def reduceroomnumber(self,reduceamount):
        if reduceamount > self.availablenumber:
            raise NegativeRoom
        self.availablenumber-=reduceamount

    def addroomnumber(self,addamount):
        self.availablenumber+=int(addamount)

    def display(self):
        return 'Price:{} Availablenumber:{}'.format(self.price, self.availablenumber)



import pandas as pd

class Restaurant:
    def __init__(self,menu={},employee=[]): 
        self.menu = menu
        self.employee=employee
    
    def addfood(self,food,price):
        self.menu[food]=price
        
    def addemployee(self,employee):
        self.employee.append(employee)
    
    def display(self):
        menu_list=[]
        price_list=[]
        emp_list=[]

        if len(self.menu)==0:
            menu_list.append("NAN")
            price_list.append("NAN")
        else:
            for item in self.menu:
                menu_list.append(item)
                price_list.append(self.menu[item])
        if len(self.employee)==0:
            emp_list.append("NAN")
        else:
            for people in self.employee:
                emp_list.append(people)

        data_menu = {'Menu':menu_list,'Price':price_list}
        menu_df = pd.DataFrame(data_menu)
        menu_df = menu_df.to_string(index=False)

        data_emp = {'Employee':emp_list}
        emp_df = pd.DataFrame(data_emp)
        emp_df = emp_df.to_string(index=False)

        return menu_df+'\n'+'\n'+emp_df


class NegativeSalary(Exception):
    def __init__(self):
        print("salary can't be negative")
        
class Employee():
    def __init__(self, name, age, hourlyrate, workhour=0, salary=0):
        self.name = name
        self.age = age
        self.workhour=workhour
        self.salary=salary
        self.hourlyrate=hourlyrate
        
    def add_work_salary(self,hours):
        self.workhour+=hours
        self.salary+=hours*self.hourlyrate
        
    def add_bonus(self,bonus):
        self.salary+=bonus
        
    def reduce_salary(self,money):
        if money > self.salary:
            raise NegativeSalary
        else:
            self.salary-=money
        
    def display(self):
        return 'Name:{} Age:{} Hourlyrate:{} Workhour:{} Salary:{}'.format(self.name, self.age, self.hourlyrate, self.workhour, self.salary)


import sys
import os
module_path = os.path.abspath(os.path.join('..'))
if module_path not in sys.path:
    sys.path.append(module_path)
from Hotel.Person.customers import Customers
class NegativeBill(Exception):
    def __init__(self):
        print("bill can't be negative")
class Children(Customers):
    def __init__(self, name, age,durationday, bill, pooltime=0):
        Customers.__init__(self, name, age,durationday,bill)
        self.pooltime=pooltime
    def add_children_pool_time(self,time):
        self.pooltime+=time
    def add_bill(self,amount):
        Customers.addbill(self,amount)
    def reduce_bill(self,amount):
        if amount > self.bill:
            raise NegativeBill
        else:
            Customers.reducebill(self,amount)
    def display(self):
        return 'Name:{} Age:{} Duration:{} bill:{} pooltime:{}'.format(self.name, self.age, self.duration, self.bill, self.pooltime)


class NegativeDiscount(Exception):
    def __init__(self):
        print("discount can't be negative")

class swimming_pool:
    def __init__(self,price):
        self.price = price

    def modifyprice(self,newprice):
        self.price=newprice

    def discountprice(self, discount=1):
        if discount < 0:
            raise NegativeDiscount
        self.price*=discount

    def display(self):
        return 'Swimming pool ticket price:{}'.format(self.price)




class NegativeBill(Exception):
    def __init__(self):
        print("bill can't be negative")
        
class Customers():#adults
    def __init__(self, name, age, durationday,bill=0):
        self.name = name
        self.age = age
        self.duration=durationday
        self.bill=bill
        
    def addbill(self,amount):
        self.bill+=amount
        
    def reducebill(self,amount):
        if amount > self.bill:
            raise NegativeBill
        else:
            self.bill-=amount
        
    def display(self):
        return 'Name:{} Age:{} Duration:{} bill:{}'.format(self.name, self.age, self.duration, self.bill)
        
  


from setuptools import setup, find_packages

setup(
    name='Hotel',
    version='1.1',
    packages=["Hotel", "Hotel.Person", "Hotel.Service"],
    license='MIT',
    description='A test python package',
	url='https://github.com/anqiubc/533-lab4',
    author=['Anqi Li','Evelyn Sugihermanto'],
    author_email='lianqi20209@gmail.com, evelynsugihermanto@yahoo.com'
)